@@ -23,7 +23,7 @@ import sys
 import os
 import argparse
 import json
-from .nxsparser import ParserTools, TableTools, TableDictTools
+from .nxsparser import ParserTools, TableTools, TableDictTools, ESRFConverter
 from .nxsargparser import (Runner, NXSArgParser, ErrorException)
 from .nxsdevicetools import (checkServer, listServers, openServer)
 #: (:obj:`bool`) True if PyTango available
@@ -365,7 +365,7 @@ class ConfigServer(object):
         return []
 
     def uploadCmd(self, ds, args, force=False, profiles=False, directory='.',
-                  mandatory=False):
+                  mandatory=False, external=None):
         """ upload the DB items from files
 
         :param ds: flag set True for datasources
@@ -380,6 +380,8 @@ class ConfigServer(object):
         :type directory: :obj:`str`
         :param mandatory: mandatory flag
         :type mandatory: :obj:`bool`
+        :param external: external import type
+        :type external: :obj:`str`
         :returns: list of XML items
         :rtype: :obj:`list` <:obj:`str`>
         """
@@ -417,6 +419,8 @@ class ConfigServer(object):
                 name = os.path.join(directory, "%s.xml" % ar)
                 with open(name, 'r') as fl:
                     txt = fl.read()
+                if external and external.lower() == "esrf":
+                    txt = ESRFConverter().convert(txt)
                 self._cnfServer.XMLString = txt
                 self._cnfServer.StoreComponent(ar)
                 if mandatory:
@@ -443,13 +447,15 @@ class ConfigServer(object):
         self._cnfServer.CreateConfiguration(args)
         return self._cnfServer.XMLString
 
-    def __describeDataSources(self, args, headers=None):
+    def __describeDataSources(self, args, headers=None, filters=None):
         """ provides description of datasources
 
         :param args: list of item names
         :type args: :obj:`list` <:obj:`str`>
         :param headers: list of output parameters
         :type headers: :obj:`list` <:obj:`str`>
+        :param filters:  filters for first column names
+        :type filters: :obj:`list` <:obj:`str`>
         :returns: list with description
         :rtype: :obj:`list` <:obj:`str`>
         """
@@ -475,18 +481,20 @@ class ConfigServer(object):
             dsxmls = self._cnfServer.DataSources(args)
             for i, xmls in enumerate(dsxmls):
                 parameters = ParserTools.parseDataSources(xmls)
-                ttools = TableTools(parameters)
+                ttools = TableTools(parameters,
+                                    headers=headers,
+                                    filters=filters)
                 ttools.title = "DataSource: '%s'" % args[i]
-                ttools.headers = headers
                 description.extend(ttools.generateList())
         else:
             dsxmls = self._cnfServer.DataSources(dss)
             xmls = ParserTools.mergeDefinitions(dsxmls).strip()
             parameters.extend(ParserTools.parseDataSources(xmls))
-            ttools = TableTools(parameters)
-            headers = ["source_name"].extend(headers)
-            if headers:
-                ttools.headers = headers
+            if "source_name" not in headers:
+                headers = ["source_name"].extend(headers)
+            ttools = TableTools(parameters,
+                                headers=headers,
+                                filters=filters)
             description.extend(ttools.generateList())
 
         if not description:
@@ -543,7 +551,7 @@ class ConfigServer(object):
         return description
 
     def __describeComponents(self, args, headers=None, nonone=None,
-                             private=False):
+                             private=False, attrs=True, filters=None):
         """ provides description of components
 
         :param args: list of item names
@@ -554,6 +562,10 @@ class ConfigServer(object):
         :type nonone: :obj:`list` <:obj:`str`>
         :param private: flag set True for components starting with '__'
         :type private: :obj:`bool`
+        :param attrs: flag set True for parsing attributes
+        :type attrs: :obj:`bool`
+        :param filters:  filters for first column names
+        :type filters: :obj:`list` <:obj:`str`>
         :returns: list with description
         :rtype: :obj:`list` <:obj:`str`>
         """
@@ -608,16 +620,17 @@ class ConfigServer(object):
 
             for i, xmls in enumerate(cpxmls):
                 parameters = ParserTools.parseFields(xmls)
-                parameters.extend(ParserTools.parseAttributes(xmls))
+                if attrs:
+                    parameters.extend(ParserTools.parseAttributes(xmls))
                 parameters.extend(ParserTools.parseLinks(xmls))
-                ttools = TableTools(parameters, nonone)
+                ttools = TableTools(parameters, nonone,
+                                    headers,
+                                    filters)
                 if dargs[i] in deps:
                     ttools.title = "Component: '%s' %s" % (
                         dargs[i], deps[dargs[i]])
                 else:
                     ttools.title = "Component: '%s'" % dargs[i]
-                if headers:
-                    ttools.headers = headers
                 description.extend(ttools.generateList())
         if not description:
             sys.stderr.write(
@@ -627,7 +640,8 @@ class ConfigServer(object):
             return ""
         return description
 
-    def __describeConfiguration(self, args, headers=None, nonone=None):
+    def __describeConfiguration(self, args, headers=None, nonone=None,
+                                attrs=True, filters=None):
         """ provides description of final configuration
 
         :param args: list of item names
@@ -636,6 +650,10 @@ class ConfigServer(object):
         :type headers: :obj:`list` <:obj:`str`>
         :param nonone: list of parameters which have to exist to be shown
         :type nonone: :obj:`list` <:obj:`str`>
+        :param attrs: flag set True for parsing attributes
+        :type attrs: :obj:`bool`
+        :param filters:  filters for first column names
+        :type filters: :obj:`list` <:obj:`str`>
         :returns: list with description
         :rtype: :obj:`list` <:obj:`str`>
         """
@@ -660,7 +678,8 @@ class ConfigServer(object):
         xmls = str(self._cnfServer.XMLString).strip()
         if xmls:
             description.extend(ParserTools.parseFields(xmls))
-            description.extend(ParserTools.parseAttributes(xmls))
+            if attrs:
+                description.extend(ParserTools.parseAttributes(xmls))
             description.extend(ParserTools.parseLinks(xmls))
         if not description:
             sys.stderr.write(
@@ -668,12 +687,14 @@ class ConfigServer(object):
                 "or -m for mandatory components \n\n")
             sys.stderr.flush()
             return ""
-        ttools = TableTools(description, nonone)
+        ttools = TableTools(description, nonone,
+                            headers=headers,
+                            filters=filters)
         if headers:
             ttools.headers = headers
         return ttools.generateList()
 
-    def describeCmd(self, ds, args, md, pr):
+    def describeCmd(self, ds, args, md, pr, headers=None, filters=None):
         """ provides description of configuration elements
 
         :param ds: flag set True for datasources
@@ -684,16 +705,30 @@ class ConfigServer(object):
         :type md: :obj:`bool`
         :param pr: flag set True for private components
         :type pr: :obj:`bool`
+        :param pr: column headers
+        :type pr: :obj:`str`
+        :param filters:  filters for first column names separated by comma
+        :type filters: :obj:`str`
         :returns: list with description
         :rtype: :obj:`list` <:obj:`str`>
 
         """
-        if ds:
-            return self.__describeDataSources(args)
-        elif not md:
-            return self.__describeComponents(args, private=pr)
+        if headers:
+            headers = str(headers).split(',')
         else:
-            return self.__describeConfiguration(args)
+            headers = None
+        if filters:
+            filters = str(filters).split(',')
+        else:
+            filters = None
+        if ds:
+            return self.__describeDataSources(args, headers, filters=filters)
+        elif not md:
+            return self.__describeComponents(
+                args, headers, private=pr, filters=filters)
+        else:
+            return self.__describeConfiguration(
+                args, headers, filters=filters)
 
     def infoCmd(self, ds, args, md, pr, profiles):
         """ Provides info for given elements
@@ -730,11 +765,9 @@ class ConfigServer(object):
         else:
             return self.__describeConfiguration(args, cpheaders, nonone)
 
-    def geometryCmd(self, ds, args, md, pr):
+    def geometryCmd(self, args, md, pr):
         """ provides geometry info for given elements
 
-        :param ds: flag set True for datasources
-        :type ds: :obj:`bool`
         :param args: list of item names
         :type args: :obj:`list` <:obj:`str`>
         :param md: flag set True for mandatory components
@@ -753,12 +786,12 @@ class ConfigServer(object):
             "trans_offset",
             "depends_on",
         ]
-        if ds:
-            return []
-        elif not md:
-            return self.__describeComponents(args, cpheaders, private=pr)
+        if not md:
+            return self.__describeComponents(args, cpheaders, private=pr,
+                                             attrs=False)
         else:
-            return self.__describeConfiguration(args, cpheaders)
+            return self.__describeConfiguration(args, cpheaders,
+                                                attrs=False)
 
     def dataCmd(self, args):
         """ provides varaible values
@@ -975,6 +1008,9 @@ class Upload(Runner):
         parser.add_argument("-i", "--directory", dest="directory",
                             default=".",
                             help=("input file directory, default: '.'"))
+        parser.add_argument("-e", "--external", dest="external",
+                            default="",
+                            help=("external format of xml, e.g. 'esrf'"))
         parser.add_argument('args', metavar='name', type=str, nargs='*',
                             help='names of components, datasources '
                             'or profiles')
@@ -990,7 +1026,8 @@ class Upload(Runner):
         cnfserver = ConfigServer(options.server, False)
         string = cnfserver.char.join(cnfserver.uploadCmd(
             options.datasources, options.args, options.force,
-            options.profiles, options.directory, options.mandatory
+            options.profiles, options.directory, options.mandatory,
+            options.external
         ))
         return string
 
@@ -1323,20 +1360,38 @@ class Describe(Runner):
 
         """
         parser = self._parser
-        parser.add_argument("-s", "--server", dest="server",
-                            help=("configuration server device name"))
-        parser.add_argument("-d", "--datasources", action="store_true",
-                            default=False, dest="datasources",
-                            help="perform operation for datasources")
-        parser.add_argument("-m", "--mandatory", action="store_true",
-                            default=False, dest="mandatory",
-                            help="make use mandatory components")
-        parser.add_argument("-p", "--private", action="store_true",
-                            default=False, dest="private",
-                            help="make use private components,"
-                            " i.e. starting with '__'")
-        parser.add_argument('args', metavar='name', type=str, nargs='*',
-                            help='names of components or datasources')
+        parser.add_argument(
+            "-s", "--server", dest="server",
+            help=("configuration server device name"))
+        parser.add_argument(
+            "-d", "--datasources", action="store_true",
+            default=False, dest="datasources",
+            help="perform operation for datasources")
+        parser.add_argument(
+            "-m", "--mandatory", action="store_true",
+            default=False, dest="mandatory",
+            help="make use mandatory components")
+        self._parser.add_argument(
+            "-c", "--columns",
+            help="names of column to be shown (separated by commas "
+            "without spaces). The possible names are: "
+            "depends_on, dtype, full_path, nexus_path, nexus_type, shape,"
+            " source, source_name, source_type, strategy, trans_type, "
+            "trans_offset, trans_vector, units, value",
+            dest="headers", default="")
+        self._parser.add_argument(
+            "-f", "--filters",
+            help="filters on the first column (separated by commas "
+            "without spaces). Default: '*'. E.g. '*:NXsample/*'",
+            dest="filters", default="")
+        parser.add_argument(
+            "-p", "--private", action="store_true",
+            default=False, dest="private",
+            help="make use private components,"
+            " i.e. starting with '__'")
+        parser.add_argument(
+            'args', metavar='name', type=str, nargs='*',
+            help='names of components or datasources')
 
     def run(self, options):
         """ the main program function
@@ -1349,7 +1404,7 @@ class Describe(Runner):
         cnfserver = ConfigServer(options.server)
         string = cnfserver.char.join(cnfserver.describeCmd(
             options.datasources, options.args, options.mandatory,
-            options.private))
+            options.private, options.headers, options.filters))
         return string
 
 
@@ -1424,9 +1479,6 @@ class Geometry(Runner):
         parser = self._parser
         parser.add_argument("-s", "--server", dest="server",
                             help=("configuration server device name"))
-        parser.add_argument("-d", "--datasources", action="store_true",
-                            default=False, dest="datasources",
-                            help="perform operation for datasources")
         parser.add_argument("-m", "--mandatory", action="store_true",
                             default=False, dest="mandatory",
                             help="make use mandatory components")
@@ -1447,7 +1499,7 @@ class Geometry(Runner):
         """
         cnfserver = ConfigServer(options.server)
         string = cnfserver.char.join(cnfserver.geometryCmd(
-            options.datasources, options.args, options.mandatory,
+            options.args, options.mandatory,
             options.private))
         return string
 
