@@ -791,6 +791,40 @@ standardComponentVariables = {
             'doc': "commission file postfix (string)"
         },
     },
+    'beamtimefname': {
+        'shortname': {
+            'default': "P09",
+            'doc': "beamline short name (string)"
+        },
+        'currentdir': {
+            'default': "/gpfs/current",
+            'doc': "beamtime file directory (string)"
+        },
+        'localdir': {
+            'default': "/gpfs/local",
+            'doc': "local file directory (string)"
+        },
+        'currentprefix': {
+            'default': "beamtime-metadata-",
+            'doc': "beamtime file prefix (string)"
+        },
+        'currentpostfix': {
+            'default': ".json",
+            'doc': "beamtime file postfix (string)"
+        },
+        'commissiondir': {
+            'default': "/gpfs/commissioning",
+            'doc': "commission file directory (string)"
+        },
+        'commissionprefix': {
+            'default': "commissioning-metadata-",
+            'doc': "commission file prefix (string)"
+        },
+        'commissionpostfix': {
+            'default': ".json",
+            'doc': "commission file postfix (string)"
+        },
+    },
     'default': {
         'control': {
             'default': None,
@@ -827,7 +861,7 @@ standardComponentVariables = {
     },
     'datasignal': {
         'signal': {
-            'default': 'signalname',
+            'default': 'defaultsignal',
             'doc': "data signal field name (string)"
         },
         'axes': {
@@ -1305,6 +1339,11 @@ standardComponentTemplateFiles = {
         'beamtimeid.ds.xml',
         'start_time.ds.xml',
     ],
+    'beamtimefname': [
+        'beamtimefname.xml',
+        'beamtimefname.ds.xml',
+        'start_time.ds.xml',
+    ],
     'default': [
         'default.xml',
         'defaultsample.xml',
@@ -1312,6 +1351,7 @@ standardComponentTemplateFiles = {
         'sample_name.ds.xml',
         'chemical_formula.ds.xml',
         'beamtime_id.ds.xml',
+        'beamtime_filename.ds.xml',
         'start_time.ds.xml',
         'end_time.ds.xml',
         'nexdatas_version.ds.xml',
@@ -1325,6 +1365,7 @@ standardComponentTemplateFiles = {
     ],
     'datasignal': [
         'datasignal.xml',
+        'defaultsignal.ds.xml',
         'signal_name.ds.xml',
         'signalname.ds.xml',
         'signal_axes.ds.xml',
@@ -1332,6 +1373,7 @@ standardComponentTemplateFiles = {
     'defaultinstrument': [
         'defaultinstrument.xml',
         'beamtime_id.ds.xml',
+        'beamtime_filename.ds.xml',
         'start_time.ds.xml',
         'end_time.ds.xml',
         'nexdatas_version.ds.xml',
@@ -1482,6 +1524,7 @@ moduleTemplateFiles = {
                'lambda_external_data.ds.xml'],
     'lambdavds': ['lambdavds.xml',
                   'lambdavds_nxdata.ds.xml',
+                  'lambdavds_description.ds.xml',
                   'lambdavds_triggermode_cb.ds.xml',
                   'lambdavds_framenumbers_cb.ds.xml',
                   'lambdavds_savefilename_cb.ds.xml'],
@@ -1491,6 +1534,14 @@ moduleTemplateFiles = {
     'dalsa': ['dalsa.xml',
               'dalsa_nxdata.ds.xml',
               'dalsa_external_data.ds.xml'],
+    'dalsavds': ['dalsavds.xml',
+                 'dalsavds_nxdata.ds.xml',
+                 'dalsavds_triggermode_cb.ds.xml',
+                 'dalsavds_filestartnum_cb.ds.xml',
+                 'dalsavds_nrexposedframes_cb.ds.xml'],
+    'lambdavdsnm': ['lambdavdsnm.xml',
+                    'lambdavdsnm_triggermode_cb.ds.xml',
+                    'lambdavdsnm_nxdata.ds.xml'],
     'lambda2m': ['lambda2m.xml',
                  'lambda2m_m1_nxdata.ds.xml',
                  'lambda2m_m2_nxdata.ds.xml',
@@ -1670,7 +1721,7 @@ moduleMultiAttributes = {
         'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
         'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
         'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
-        'LiveLastImageData', 'FramesPerFile', 'OpMode'
+        'LiveLastImageData', 'FramesPerFile', 'OpMode', 'Translations'
     ],
     'lambdavds': [
         'TriggerMode', 'ShutterTime', 'DelayTime', 'FrameNumbers', 'ThreadNo',
@@ -1680,7 +1731,17 @@ moduleMultiAttributes = {
         'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
         'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
         'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
-        'LiveLastImageData', 'FramesPerFile', 'OpMode'
+        'LiveLastImageData', 'FramesPerFile', 'OpMode', 'Translations'
+    ],
+    'lambdavdsnm': [
+        'TriggerMode', 'ShutterTime', 'DelayTime', 'FrameNumbers', 'ThreadNo',
+        'EnergyThreshold', 'OperatingMode', 'ConfigFilePath', 'SaveAllImages',
+        'FilePrefix', 'FileStartNum', 'FilePreExt', 'FilePostfix',
+        'SaveFilePath', 'SaveFileName', 'LatestImageNumber', 'LiveMode',
+        'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
+        'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
+        'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
+        'LiveLastImageData', 'FramesPerFile', 'OpMode', 'Translations'
     ],
     'lambda2m': [
         'TriggerMode', 'ShutterTime', 'DelayTime', 'FrameNumbers', 'ThreadNo',
@@ -1690,7 +1751,7 @@ moduleMultiAttributes = {
         'TotalLossFrames', 'CompressorShuffle', 'CompressionRate',
         'CompressionEnabled', 'Layout', 'ShutterTimeMax', 'ShutterTimeMin',
         'Width', 'Height', 'Depth', 'LiveFrameNo', 'DistortionCorrection',
-        'LiveLastImageData', 'OpMode'
+        'LiveLastImageData', 'OpMode', 'Translations'
     ],
     'pedetector': [
         'BinningMode', 'FileIndex', 'ExposureTime', 'SkippedAtStart',
@@ -1744,4 +1805,16 @@ moduleMultiAttributes = {
         'LinearityEqualizer', 'NrExposedFrames', 'NrOffsetFrames',
         'Offset', 'PixelFormat', 'ReadOutMode', 'Standby', 'SumScheme'
     ],
+    'dalsavds': [
+        'FileDir', 'FilePostfix', 'FilePrefix', 'FileSaving', 'FileStartNum',
+        'TriggerMode', 'Width', 'Height', 'ExtendedExposure',
+        'BinComment',
+        'FramesProcessed', 'Image16', 'Image8', 'ImageRaw',
+        'FramesReceived', 'FrameRate', 'FramesPerNXFile', 'NXFileCompression',
+        'TurboMode', 'ImageEnc', 'ViewingMode',
+        'ThrashedBuffers', 'FramesToAcquire',
+        'AcquisitionFrameCount', 'AcquisitionMode', 'AcquisitionFrameMode',
+        'LinearityEqualizer', 'NrExposedFrames', 'NrOffsetFrames',
+        'Offset', 'PixelFormat', 'ReadOutMode', 'Standby', 'SumScheme'
+    ],
 }
